#
# spec file for package python-argparse-manpage
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_name argparse-manpage
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-argparse-manpage
Version:        1.3
Release:        lp151.5.1
Summary:        Tool for automatic manual page building from a Python ArgumentParser object
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/praiskup/argparse-manpage
Source:         https://github.com/praiskup/argparse-manpage/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post):   update-alternatives
Requires(postun):  update-alternatives
%python_subpackages

%description
This utility generates a manual page in an automatic way from an
ArgumentParser object, so the manpage 1:1 corresponds to the
automatically generated --help output. The manpage generator needs to
known the location of the object, user can specify that by (a) the
module name or corresponding python filename and (b) the object name
or the function name which returns the object. There's a limited
support for (deprecated) optparse objects, too.

%prep
%setup -q -n %{mod_name}-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/argparse-manpage
%python_clone -a %{buildroot}%{_mandir}/man1/argparse-manpage.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%{python_install_alternative argparse-manpage argparse-manpage.1}

%postun
%python_uninstall_alternative argparse-manpage

%files %{python_files}
%doc README*
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/argparse-manpage
%python_alternative %{_mandir}/man1/argparse-manpage.1%{?ext_man}

%changelog
* Thu Aug 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Resubmit for SLE (jsc#SLE-12826)
* Tue Apr 14 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Fri Jan 31 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require python-setuotools: /usr/bin/argparse-manpage does
  from pkg_resources import load_entry_point.
* Fri Jan 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.3
  * drop additional .br tag from paragraphs so the multiline text is nicer
  * provide argparse-manpage via entry_point
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.2:
  * More complete release tarball, including tests.
  * Fixed shebang in /bin/argparse-manpage script so it works on
    Debian/Ubuntu as well as on Fedora.
  * LICENSE file included in release tarball.
  * Command-line executable now takes an optional '--output' argument.
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball
  - Enable tests
  - Get license file
- Run fdupes
- Add support for older distros than Tumbleweed
* Fri Oct 12 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Repair grammar issues in description.
* Thu Oct 11 2018 Marcus Rueckert <mrueckert@suse.de>
- initial package
